pygenstub
=========

.. include:: ../../README.rst

.. tip::

   pygenstub can be used with PyCharm file watchers to update stub files
   automatically when source files are modified.


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   features
   api
   history
